<?php

namespace Illuminate\Tests\Integration\Database\SqlServer;

use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Schema;

class DatabaseSqlServerSchemaBuilderTest extends SqlServerTestCase
{
    protected function afterRefreshingDatabase()
    {
        Schema::create('users', function (Blueprint $table) {
            $table->integer('id');
            $table->string('name');
            $table->string('age');
            $table->enum('color', ['red', 'blue']);
        });
    }

    protected function destroyDatabaseMigrations()
    {
        Schema::drop('users');
        DB::statement('drop view if exists users_view');
    }

    public function testGetTables()
    {
        DB::statement('create view users_view AS select name, age from users');

        $rows = Schema::getTables();

        $this->assertGreaterThanOrEqual(2, count($rows));
        $this->assertTrue(
            collect($rows)->contains('name', 'migrations'),
            'Failed asserting that table "migrations" was returned.'
        );
        $this->assertTrue(
            collect($rows)->contains('name', 'users'),
            'Failed asserting that table "users" was returned.'
        );
        $this->assertFalse(
            collect($rows)->contains('name', 'users_view'),
            'Failed asserting that view "users_view" was not returned.'
        );
    }

    public function testColumnListing()
    {
        $this->assertSame(['id', 'name', 'age', 'color'], Schema::getColumnListing('users'));
    }

    public function testGetViews()
    {
        DB::statement('create view users_view AS select name, age from users');

        $rows = Schema::getViews();

        $this->assertCount(1, $rows);
        $this->assertSame('users_view', $rows[0]['name']);
    }

    public function testGetViewsWhenNoneExist()
    {
        $this->assertSame([], Schema::getViews());
    }
}
